# Generated by roxygen2: do not edit by hand

export("%>%")
export(add_rarefaction_metrics)
export(fit_neutral_model)
export(identify_core)
export(multi_rarefy)
export(plot_abundance_occupancy)
export(plot_core_distribution)
export(plot_identified_core)
export(plot_neutral_model)
export(plot_rarefaction_metrics)
export(plot_variance_propagation)
export(sncm.fit)
export(update_otu_table)
importFrom(Hmisc,binconf)
importFrom(cli,cli_abort)
importFrom(cli,cli_alert_danger)
importFrom(cli,cli_alert_info)
importFrom(cli,cli_alert_success)
importFrom(cli,cli_alert_warning)
importFrom(cli,cli_h1)
importFrom(cli,cli_h2)
importFrom(cli,cli_inform)
importFrom(cli,cli_progress_step)
importFrom(cli,cli_text)
importFrom(cli,cli_warn)
importFrom(dplyr,across)
importFrom(dplyr,all_of)
importFrom(dplyr,arrange)
importFrom(dplyr,bind_rows)
importFrom(dplyr,desc)
importFrom(dplyr,everything)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,last)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,n)
importFrom(dplyr,near)
importFrom(dplyr,select)
importFrom(dplyr,slice_head)
importFrom(dplyr,summarise)
importFrom(dplyr,summarize)
importFrom(dplyr,transmute)
importFrom(dplyr,ungroup)
importFrom(dplyr,where)
importFrom(ggplot2,aes)
importFrom(ggplot2,after_scale)
importFrom(ggplot2,alpha)
importFrom(ggplot2,annotate)
importFrom(ggplot2,coord_cartesian)
importFrom(ggplot2,coord_flip)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_line)
importFrom(ggplot2,element_rect)
importFrom(ggplot2,element_text)
importFrom(ggplot2,expansion)
importFrom(ggplot2,facet_wrap)
importFrom(ggplot2,geom_bar)
importFrom(ggplot2,geom_boxplot)
importFrom(ggplot2,geom_histogram)
importFrom(ggplot2,geom_jitter)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_tile)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,guide_legend)
importFrom(ggplot2,guides)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,scale_x_discrete)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,scale_y_log10)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,theme_classic)
importFrom(ggpubr,ggarrange)
importFrom(ggrepel,geom_text_repel)
importFrom(grid,unit)
importFrom(magrittr,"%>%")
importFrom(minpack.lm,nlsLM)
importFrom(phyloseq,"sample_data<-")
importFrom(phyloseq,otu_table)
importFrom(phyloseq,phy_tree)
importFrom(phyloseq,phyloseq)
importFrom(phyloseq,prune_samples)
importFrom(phyloseq,prune_taxa)
importFrom(phyloseq,refseq)
importFrom(phyloseq,sample_data)
importFrom(phyloseq,sample_names)
importFrom(phyloseq,sample_sums)
importFrom(phyloseq,tax_table)
importFrom(phyloseq,taxa_are_rows)
importFrom(phyloseq,taxa_sums)
importFrom(rlang,.data)
importFrom(rlang,as_name)
importFrom(rlang,ensym)
importFrom(scales,comma)
importFrom(stats,AIC)
importFrom(stats,BIC)
importFrom(stats,IQR)
importFrom(stats,coef)
importFrom(stats,confint)
importFrom(stats,dnorm)
importFrom(stats,pbeta)
importFrom(stats,pbinom)
importFrom(stats,ppois)
importFrom(stats,quantile)
importFrom(stats4,mle)
importFrom(tibble,as_tibble)
importFrom(tibble,column_to_rownames)
importFrom(tibble,rownames_to_column)
importFrom(tidyr,pivot_longer)
importFrom(utils,combn)
importFrom(utils,head)
importFrom(utils,tail)
importFrom(vegan,decostand)
importFrom(vegan,rrarefy)
