#' 16S amplicon dataset from Switchgrass (Panicum virgatum)
#'
#' @description A phyloseq containing 706 97% sequence similarity OTUs
#' (Operational Taxonomic Units) across 43 samples.
#'
#' @usage data("switchgrass")
#' @docType data
#' @format An object class "phyloseq".
#'
#' @references Shade A, Stopnisek N (2019) Abundance-occupancy distributions to
#' prioritize plant core microbiome membership. Current Opinion in
#' Microbiology, 49:50-58 <doi:10.1016/j.mib.2019.09.008>
#'
#' @source Internal test dataset.
"switchgrass"

#' Identified core microbiome members for the switchgrass dataset
#'
#' @description A phyloseq containing the identified core microbiome members
#' for the switchgrass dataset. This object is used for BRCore function
#' examples.
#' It was generated by running the following on BRCore 2.0.2 (2026-04-30):
#' ```R
#' switchgrass_core <- identify_core(
#'   physeq_obj     = switchgrass,
#'   priority_var   = "sampling_date",
#'   increase_value = 0.02,
#'   seed           = 092825
#' )
#' ```
#'
#' @usage data("switchgrass_core")
#' @docType data
#' @format An object class "phyloseq".
#'
#' @references Shade A, Stopnisek N (2019) Abundance-occupancy distributions to
#' prioritize plant core microbiome membership. Current Opinion in
#' Microbiology, 49:50-58 <doi:10.1016/j.mib.2019.09.008>
#'
#' @source Internal test dataset.
"switchgrass_core"

#' 16S amplicon dataset from yellow monkeyflower (Mimulus guttatus)
#'
#' @description A phyloseq containing 11085 ASVs (Amplicon Sequence Variants)
#'  across 39 samples.
#'
#' @usage data("mimulus")
#' @docType data
#' @format An object class "phyloseq".
#'
#' @references Shade A, Stopnisek N (2019) Abundance-occupancy distributions to
#' prioritize plant core microbiome membership. Current Opinion in
#' Microbiology, 49:50-58 <doi:10.1016/j.mib.2019.09.008>
#'
#' @source Internal test dataset.
"mimulus"

#' 16S amplicon dataset from common bean (Phaseolus vulgaris)
#'
#' @description A phyloseq containing 24885 ASVs (Amplicon Sequence Variants)
#' across 30 samples.
#'
#' @usage data("bean")
#' @docType data
#' @format An object class "phyloseq".
#'
#' @references Shade A, Stopnisek N (2019) Abundance-occupancy distributions to
#' prioritize plant core microbiome membership. Current Opinion in
#' Microbiology, 49:50-58 <doi:10.1016/j.mib.2019.09.008>
#'
#'
#' @source Internal test dataset.
"bean"

#' 16S amplicon dataset from the GLBRC Biofuel Cropping System Experiment
#' (BCSE) at Michigan State University, Kellogg Biological Station
#'
#' @description A phyloseq containing 2861 97% sequence similarity OTUs
#' (Operational Taxonomic Units) across 50 samples. Samples are for the leaf
#' microbiome only.
#'
#' @usage data("bcse")
#' @docType data
#' @format An object class "phyloseq".
#'
#' @references Haan, N. L., Benucci, G. N. M., Fiser, C. M., Bonito, G., &
#' Landis, D. A. (2023). Contrasting effects of bioenergy crops on
#' biodiversity. Science Advances, 9(38), eadh7960.
#' <doi:10.1126/sciadv.adh7960>

#'
#' @source Internal test dataset.
"bcse"
